<?php
namespace Teknisa\COZ\Services;

use Teknisa\GER\Utilities\Util;
use Teknisa\GER\Utilities\Environment;
use Teknisa\COZ\Services\Coz10600RemoteRepository;

class Coz10600Service{

    public $environment;
    protected $util;
    protected $coz10600remoteRepository;

    public function __construct($environment, $util, $coz10600remoteRepository){
        $this->environment = $environment;
        $this->util = $util;
        $this->coz10600remoteRepository = $coz10600remoteRepository;
    }

    public function retornaFiliais($row){
        if($row['TODOSFILIAL'] === 'S'){
            $row['CDGRUPFILI'] = ($row['CDGRUPFILI'] === '' ? 'T' : $row['CDGRUPFILI']);

            $fieldsToFilter = array("NRORG", "CDGRUPFILI", "CDCENTRAL");
            $paramObjectArray = $this->buildFilterArrayFromRow($row, $fieldsToFilter);

            $row['NMFILIAL'] = $this->coz10600remoteRepository->fetchFiliais($paramObjectArray);
        }
        return $this->concatArray($row['NMFILIAL']);
    }

    public function retornaGrupServ($row){
        if($row['TODOSGRUPSERV'] === 'S'){   
            $row['NMGRUPSERV'] = $this->coz10600remoteRepository->fetchGrupserv();
        }
        return $this->concatArray($row['NMGRUPSERV']);
    }

    public function retornaServico($row){
        if($row['TODOSSERVICO'] === 'S'){
            $row['CDGRUPFILI'] = ($row['CDGRUPFILI'] === '' ? 'T' : $row['CDGRUPFILI']);
            $row['CDGRUPSERV'] = $row['LISTAGRUPSERV'];
            $row['CDFILIAGREGA'] = $row['LISTAFILIAL'];

            $fieldsToFilter = array("NRORG", "CDGRUPFILI", "CDCENTRAL", "CDGRUPSERV", "CDFILIAGREGA");
            $paramObjectArray = $this->buildFilterArrayFromRow($row, $fieldsToFilter);

            $row['SERVICOFILIAL'] = $this->coz10600remoteRepository->fetchServicos($paramObjectArray);
        }
        return $row['SERVICOFILIAL'];
    }

    public function retornaProduto($row){
        if($row['TODOSPRODUTO'] === 'S'){

            /*
            $fieldsToFilter = array("NRORG", "CDCENTRAL", "CDNVPRODUTO");
            $paramObjectArray = $this->buildFilterArrayFromRow($row, $fieldsToFilter);

            $row['NMPRODUTO'] = $this->coz10600remoteRepository->fetchProdutos($paramObjectArray);
            */

            //  Colocar T em cima da lista por causa do relatório
            return 'T';
        } else{
            return $this->concatArray($row['NMPRODUTO']);
        }
    }

    public function concatArray($array, $key = false){
        if ($key){
            $string = '';
            foreach ($array as $item) {
              $string .= $item[$key].'_';
            }
            return trim($string, '_');
        }
        else return implode($array, "_");
    }

    /*
     * Constroi um array de arrays a partir de uma row, no formato chave=>valor,
     * e um array de strings especificando quais das colunas deverão ser usadas
     */
    public function buildFilterArrayFromRow($row, $filterKeys){
        //pega todos os valores de $row com chaves presentes em $filterKeys
        //o array_flip faz com que os valores de $filterKeys sejam chaves
        $paramValueArray = array_intersect_key($row, array_flip($filterKeys));

        return array_map(function($key, $value){
            return array("columnName"=>$key, "operator"=>"=", "value"=>$value); 
        }, array_keys($paramValueArray), $paramValueArray);
    }
}